package org.springblade.modules.api.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springblade.common.constant.CommonConstant;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.entity.UserMerchant;
import org.springblade.modules.system.service.IUserMerchantService;
import org.springblade.modules.system.service.IUserService;
import org.springblade.modules.system.vo.UserMerchantVO;
import org.springframework.util.Assert;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * Author pangqijun
 * Date 2024/7/16
 * Description
 */
@RestController
@AllArgsConstructor
@RequestMapping(CommonConstant.API_URL)
@Api(value = "商家端", tags = "商家端用户接口")
public class ApiMerchantUserController {

    private final IUserMerchantService iUserMerchantService;
    private final IUserService iUserService;

    @GetMapping("/merchant/get")
    @ApiOperationSupport(order = 1)
    @ApiOperation(value = "获取商家用户信息")
    public R<UserMerchantVO> getMerchantUserInfo() {
        User user = iUserService.getById(AuthUtil.getUserId());
        Assert.notNull(user, "未查询到用户信息");
        UserMerchantVO vo = iUserMerchantService.getByUserId(user.getId());
        vo.setAvatar(user.getAvatar());
        vo.setName(user.getName());
        vo.setRealName(vo.getRealName());
        vo.setPhone(user.getPhone());
        return R.data(vo);
    }
}
